trace_stack

Attribute Macro trace_stack 

#[trace_stack]
Wrap a function body in a stack trace guard and a turso_stack tracing span.

With no arguments, the label is inferred as module_path!()::function_name and the span name is the function name. A string literal argument overrides the label.

#[turso_macros::trace_stack]
fn prepare_select_plan(...) { ... }

#[turso_macros::trace_stack("select:translate")]
fn translate_select(...) { ... }

#[turso_macros::trace_stack(detail = stmt_kind(&stmt))]
fn translate_inner(stmt: ast::Stmt, ...) { ... }